#!/bin/sh

syslogd
killall udhcpc

msg(){ 
	if [ -n "$1" ]; then
		dialog --keep-window  --infobox "$1" 10 70
	fi
	lastmsg="$1"
	return 0
}

msgok(){
	[ ! -e /tmp/debug ] && dialog --msgbox "$1" 10 70
	[ -e /tmp/debug ] && echo "$1" && echo "ENTER to continue" && read forget
}

if [ "$1" ]; then
	SERVER_INTERFACE=$1
else
	SERVER_INTERFACE=$( grep -e : /proc/net/dev | grep -v lo | awk -F: '{ print $1 }' )
fi

# ip to use normally
MYIP=10.0.66.1


if [ "$( echo $SERVER_INTERFACE | wc  | awk '{ print $2 }' )" != "1" ]; then
	OPTIONS=""
	for i in $SERVER_INTERFACE; do
		OPTIONS="$OPTIONS $i $i"
	done

	dialog --menu "Choose network interface to use as PXE server" 15 50 10 $OPTIONS 2> /tmp/menu
	SERVER_INTERFACE=$( cat /tmp/menu )
fi

# setup network, if not already on
echo "Will use network interface $SERVER_INTERFACE"

if ! ifconfig | grep lo > /dev/null ; then
	ifconfig lo 127.0.0.1 up
fi
if ! ifconfig | grep -B1 "inet addr" | grep $SERVER_INTERFACE > /dev/null ; then
	ifconfig $SERVER_INTERFACE $MYIP up
	[ "$?" != "0" ] && msgok "Error setting network address. Abortando" && exit 1
else
	MYIP=$( ifconfig | grep -A5 $SERVER_INTERFACE | grep "inet addr" | awk '{ print $2 }' | awk -F: '{ print $2 }' )
fi

# update udhcp 
MYNET=$( echo $MYIP | awk -F. '{ print $1 "." $2 "." $3 }' )
if [ "$MYNET" != "192.168.0" ]; then
	sed "s/192.168.0/$MYNET/g" /etc/udhcpd.conf.template >/etc/udhcpd.conf
fi

sed -i "s/^interface.*/interface $SERVER_INTERFACE/g" /etc/udhcpd.conf

# start services.

inetd
[ "$?" != "0" ] && msgok "Error starting inetd. Abortando" && exit 1

udhcpd
[ "$?" != "0" ] && msgok "Error starting DHCP. Abortando" && exit 1

mkdir -p /tmp/tftproot/pxelinux.cfg/
cp /usr/lib/syslinux/pxelinux.0 /tmp/tftproot/
sed "s#/cdrom/#$MYIP:/#g" /tmp/boot-copy/isolinux.cfg  | sed 's/\(append.*\)/\1 recovery=net/g' > /tmp/tftproot/pxelinux.cfg/default

ln -s /tmp/boot-copy/* /tmp/tftproot/

(cd /tmp/tftproot/ && httpd . )


[ "$?" != "0" ] && msgok "Error starting http. Abortando" && exit 1

exit 0


