#!/bin/sh


n=0
function do_copy {
	if [ ! -e "$1" ]; then
		error "Can't open \"$1\" file. Does it exist?"
		return 1
	fi

	ERROR_CP=0
	for f in $(cat "$1"); do
		# type 1; commented (by "#")
		if echo $f | grep "^#" > /dev/null; then
			#echo skip $f
			continue
		fi
		orig=
		# type 2; optional files (begin with "(optional)")
		optional=`echo $f | grep "^(optional)"`
		if [ -n "$optional" ]; then
			file=`echo $f | cut -c 11-`
		else
			file=$f
		fi
		DONE=""
		# type 3; Alternatives (separated by "|")
		for ff in `echo $file | awk -F '|' '{for (i=1; i<=NF; i++) print $i}'`
		do
			if ! [ -e "$orig" ] # if no valid alternative found yet
			then

				if echo $ff | grep ":" > /dev/null; then
					FIRST=`echo $ff | awk -F ':' '{print $1}'`
					if [ "$FIRST" == "findicon" ]
					then 
						# type 4; copy icons
						WHERE=`echo $ff | awk -F ':' '{print $2}'`
						ICON_NAME=`echo $ff | awk -F ':' '{print $3}'`

						if ! [ -e ./usr/share/icons/$WHERE/index.theme ]
						then
							mkdir -p ./usr/share/icons/$WHERE
							cp /usr/share/icons/$WHERE/index.theme ./usr/share/icons/$WHERE/index.theme
						fi

						if [ -n "$WHERE" -a -n "$ICON_NAME" ]
						then
							for i in `find /usr/share/icons/$WHERE -name "$ICON_NAME.png"`
							do
								mkdir -p ./$( dirname $i )
								cp -a $i ./$i
							done
						fi
						DONE=true
					else
						# type 5; copy to other place (source:dest)
						orig=$( get_file $( echo $ff | awk -F: '{ print $1 }' ) "${BOOTCD_BASE_DIR};${RPWD}" --critical )
						dest=./$( echo $f | awk -F: '{ print $2 }' )
						dirname=./$( dirname ${dest}test )/
					fi
				else
					# type 6; binary (without "/")
					if echo $ff | grep "/" > /dev/null; then
						file=$ff
					else
						file=`which $ff`
					fi
					if [ -n "$file" ]
					then
						dirname=./$( dirname $file )/
					else
						if [ -z "$optional" ]; then
							error "Cannot find $ff"
						fi
					fi
					orig=$file
					dest=./$dirname
				fi
			fi
		done
		#echo -n -e "\r" "$orig" "->" "./$dest ($dirname) "

		if [ -z "$DONE" ]
		then
			mkdir -p "$dirname"
			if [ "$?" != "0" ]; then return 1; fi

			cp -a "$orig" "./$dest" 2>/dev/null
			if [ "$?" != "0" ]; then 
				if [ -z "$optional" ]; then
					error "Error copying '$orig'"
					ERROR_CP=1
				fi
			fi
		fi

		n=$[ $n + 1 ]
	done
	return $ERROR_CP
}

# copy the deb package contents to the bootcd, and the dependencies
# it is not very smart with dependencies, just the first if there is a  |
function do_copy_deb {
	fdeb=$1
	# comment
	if echo $fdeb | grep "^#" > /dev/null; then
		return
	fi
	if echo "$debs_in" | grep $fdeb > /dev/null; then
		#echo "                Not again"
		return
	fi
	#echo "Copy deb files: $1"
	debs_in="$debs_in $fdeb"
	n=0
	for f in $( dpkg -L $fdeb | grep -v ":" ); do 
		if [ -f "$f" -a ! -e "./$f" ]; then 
			something=1
			mkdir -p $( dirname ./$f )
			cp -a $f ./$f
			if [ "$?" != "0" ]; then
				error "$fdeb error copyng file $f"
				ERROR_CP=4
			fi
			n=$[ $n + 1 ]
		else if [ ! -e "$f" ]; then
				error "$f not found for $fdeb."
				ERROR_CP=5
			fi
		fi
	done 
	echo "Copied deb files $1, count of files: $n"

	deps=$( dpkg -p $fdeb | grep ^Depends: | sed -e 's/|[^,]*//g' -e 's/([^)]*)//g' -e 's/,//g' -e "s/^Depends://g" )
	for dep in $deps; do
			do_copy_deb $dep
	done
}

function do_postcp {
	$1
	if [ "$?" != "0" ]; then
		error "Error executing postcp"
		exit 1
	fi
}

pdone=''

function do_packagefiles_cp {
	local p=0
	ERROR_CP=0
	for p in "$@"; do

		#message "Package $p ${FILEPACKAGES_DIRS}"

		something=0

		if echo $pdone | grep $p > /dev/null; then
			#message "$p already in"
			continue
		fi
		pdone="$pdone $p"
		deps=$( get_file $p.deps "${FILEPACKAGES_DIRS}" )
		if [ ! -z "$deps" ]; then
			something=1
			#message "Dependencies of $p": $( cat $deps | grep -v "^#" )
			do_packagefiles_cp $( cat $deps | grep -v "^#" )
		fi

		sizestart=$( du -sbk . | awk '{ print $1 }' )

		files=$( get_file $p.files "${FILEPACKAGES_DIRS}" )
		if [ ! -z "${files}" ]; then
			something=1
			#message "       files"
			do_copy "${files}"
			if [ "$?" != "0" ]; then
				error "Error on files file '$files'"
				ERROR_CP=3
			fi
		fi

		fdeb=$( get_file $p.fdeb "${FILEPACKAGES_DIRS}" )
		if [ ! -z "$fdeb" ]; then
			something=1
			message "Files for $p, from deb descriptions"
			for fdeb in $( cat $fdeb ); do
				do_copy_deb $fdeb
			done
		fi

		postcp=$( get_file $p.postcp "${FILEPACKAGES_DIRS}" )
		if [ ! -z "${postcp}" ]; then
			something=1
			do_postcp "${postcp}"
			#message "       Postcp $p $?"
		fi

		sizeend=$( du -sbk . | awk '{ print $1 }' )

		message "Package $p ($(( $sizeend - $sizestart )) KB)"

		if [ "$something" == "0" ]; then
			error "Nothing to do at package $p. Remove it if you dont really need it"
			exit 2
		fi
	
	done
	if [ "$ERROR_CP" != "0" ]; then
		error "Cant copy files"
		exit 1
	fi
	return $ERROR_CP
}

do_packagefiles_cp "base" "$@"

size=$( du -sbm . | awk '{ print $1 }' )


echo "$n files  ($size MB)"
# now check libs
message "Copy library depends"
n=0
l=0
#for f in $( find .  -perm /111 -a '!' -type d -a '!' -type l ); do
for f in $( find . '!' -type d -a '!' -type l ); do
	for i in $( ldd $f  2>/dev/null | grep -v linux-gate.so.1 | awk '{print $(NF-1)}' | grep "^/" ); do
		LINK=`readlink $i`
		if [ -z "$LINK" ]
		then
			if [ ! -a ./$i ]
			then
				mkdir -p $( dirname ./$i )
				cp -R -d -p $i ./$i
				if [ "$?" != "0" ]; then
					error "Cant copy library '$i', dependency for $f"
					exit 3
				fi
			fi
		else
			LINK=`readlink -f $i`
			if [ ! -a ./$LINK ]
			then
				mkdir -p $( dirname ./$LINK )
				cp -R -d -p $LINK ./$LINK
				if [ "$?" != "0" ]; then
					error "Cant copy library '$LINK', dependency for $f (real file)"
					exit 3
				fi
			fi
			if [ ! -h ./$i ]
			then
				mkdir -p $( dirname ./$i )
				ln -s $LINK ./$i
				if [ "$?" != "0" ]; then
					error "Cant copy library '$i', dependency for $f (link)"
					exit 3
				fi
			fi
			l=$[ $l + 1 ]
		fi

		n=$[ $n + 1 ]
	done
done
sizeend=$( du -sbm . | awk '{ print $1 }' )

echo "$n dependencies ($l links, $(( $sizeend - $size )) MB)"

