GRUBDIR=$ISO/boot/grub/

message "Preparing ISO image... (grub boot)"

mkdir -p $GRUBDIR
if [ ! -e "$GRUB_ELTORITO" ]; then
	error "Cant find eltorito grub image ('$GRUB_ELTORITO'). Force it with GRUB_ELTORITO option."
	exit 1
fi
cp "$GRUB_ELTORITO" $GRUBDIR

# only if there is a stage2
if [ ! -z "$FILEPACKAGES" ]; then 
	ROOT="root=/cdrom/stage2.squashfs"
fi

# init2 is init for stage 2. Be it in a squashfs or at initrd.
if [ -z "$INIT" ]; then
	INIT2="init2=/sbin/init"
else
	INIT2="init2=$INIT"
fi

# whether the stage2 image should be copied to ram and booted there (so CDROM is ejectable)
if [ "$IMAGE_TO_RAM" == "1" ]; then
	IMAGE_TO_RAM="image_to_ram=ok"
fi

cat > $GRUBDIR/menu.lst <<EOF
timeout 3
foreground 0000c3
background cccccc
#splashimage /boot/grub/boot-logo.xpm

title ${CDTITLE}
root (cd)
kernel /boot/linux $RW $ROOT $INIT2 $IMAGE_TO_RAM quiet
initrd /boot/initrd.gz

# quiet
EOF

cd $BOOTCD_TEMP

mv $BOOTCD_TEMP/initrd.gz $ISO/boot/
if [ ! -e "$KERNEL_IMAGE" ]; then
	error "Cant find linux kernel '$KERNEL_IMAGE'. Set it with KERNEL_IMAGE option"
	exit 1
fi
cp $KERNEL_IMAGE $ISO/boot/linux

echo "${CDTITLE}" > $ISO/.tuxum_bootcd

genisoimage -R -b boot/grub/stage2_eltorito -no-emul-boot \
         -boot-load-size 4 -boot-info-table -o "${FINAL_ISO}" iso 2>/dev/null >/dev/null

if [ "$?" != "0" ];then
	error "Error creating ISO image"
	echo genisoimage -R -b boot/grub/stage2_eltorito -no-emul-boot \
         -boot-load-size 4 -boot-info-table -o "${FINAL_ISO}" iso
	exit 1
fi

size=$( du -h ${FINAL_ISO} | awk '{ print $1 }' )
message_ok "Image ready at ${FINAL_ISO}"
message_ok "Size is $size"
