BOOTDIR=$ISO/boot/

ISOLINUX="/usr/lib/syslinux/isolinux.bin"

message "Preparing ISO image... (isolinux boot)"

mkdir -p $BOOTDIR

if [ ! -e "$ISOLINUX" ]; then
	error "Cant find islinux.bin image.  Please install isolinux/syslinux."
	exit 1
fi
cp "$ISOLINUX" $BOOTDIR

# only if there is a stage2
if [ ! -z "$FILEPACKAGES" ]; then 
	ROOT="root=/cdrom/stage2.squashfs"
fi

# init2 is init for stage 2. Be it in a squashfs or at initrd.
if [ -z "$INIT" ]; then
	INIT2="init2=/sbin/init"
else
	INIT2="init2=$INIT"
fi

# whether the stage2 image should be copied to ram and booted there (so CDROM is ejectable)
if [ "$IMAGE_TO_RAM" == "1" ]; then
	IMAGE_TO_RAM="image_to_ram=ok"
fi

cat > $ISO/isolinux.cfg <<EOF
default install
label install
kernel /boot/linux
append initrd=/boot/initrd.gz $RW quiet $ROOT $INIT2 $IMAGE_TO_RAM
display screen.txt
prompt 0
timeout 10
EOF

cd $BOOTCD_TEMP

mv $BOOTCD_TEMP/initrd.gz $ISO/boot/
if [ ! -e "$KERNEL_IMAGE" ]; then
	error "Cant find linux kernel '$KERNEL_IMAGE'. Set it with KERNEL_IMAGE option"
	exit 1
fi

if [ ! -e $ISO/boot/linux ]
then
	cp $KERNEL_IMAGE $ISO/boot/linux
fi

echo "${CDTITLE}" > $ISO/.tuxum_bootcd

genisoimage -R -o "${FINAL_ISO}" -b boot/isolinux.bin -c boot/boot.cat -no-emul-boot \
	-boot-load-size 4 -boot-info-table iso 2>/dev/null >/dev/null

if [ "$?" != "0" ];then
	error "Error creating ISO image"
	echo genisoimage -R -o "${FINAL_ISO}" -b boot/isolinux.bin -c boot/boot.cat -no-emul-boot \
	-boot-load-size 4 -boot-info-table iso
	exit 1
fi

size=$( du -h ${FINAL_ISO} | awk '{ print $1 }' )
message_ok "Image ready at ${FINAL_ISO}"
message_ok "Size is $size"
