#!/bin/bash

if [ -e "$( dirname $0 )/sh/basefunctions.sh" ]; then
	BOOTCD_BASE_DIR=$( cd $( dirname $0 ) && pwd )
else
	BOOTCD_BASE_DIR=/usr/share/apps/tuxum-bootcd/
fi


. ${BOOTCD_BASE_DIR}/sh/basefunctions.sh

message "Base dir at ${BOOTCD_BASE_DIR}"

if [ ! -e bootcd.config ]; then
	error "ERROR: bootcd.config does not exist at current dir!"
	echo
	echo "Look at the documentation for help on how to create one"
	echo
	exit 1
fi

. ${BOOTCD_BASE_DIR}/globalconfig.bootcd

# use a given config file or default named bootcd.config
if [ ! -z "$1" ]; then
	. $1
else
	. ./bootcd.config
fi


if [ -z "${KERNEL_VERSION}" ]; then
	KERNEL_VERSION=$( uname -r )
	message "Automatic kernel version $KERNEL_VERSION"
fi

if [ -z "${KERNEL_IMAGE}" ]; then
	KERNEL_IMAGE="/boot/vmlinuz-${KERNEL_VERSION}"
	message "Automatic kernel image $KERNEL_IMAGE"
fi

if [ ! -e "${KERNEL_IMAGE}" ]; then
	error "Cant find a suitable kernel image. Please set the KERNEL_IMAGE option"
	exit 1
fi

export PATH=$PATH:${BOOTCD_BASE_DIR}/sh/
export RPWD=$( pwd )

# basic sanity checks...

if [ -z "${BOOTCD_TEMP}" -o -z "${FINAL_ISO}" -o -z "${BOOT_MODULES_FILES}"  ]; then
	error "I need at least the following config vars: BOOTCD_TEMP FINAL_ISO BOOT_MODULES_FILES"
	exit 1
fi


ISO=${BOOTCD_TEMP}/iso/

export ISO
export BOOTCD_BASE_DIR
export PATH
export BOOTCD_TEMP
export KERNEL_VERSION
export SPLASH_IMAGE
export CDVERSION
export BOOT_TYPE

rm -rf ${BOOTCD_TEMP}
mkdir -p ${BOOTCD_TEMP}
mkdir -p $ISO

cd ${BOOTCD_TEMP}

. do_initrd.sh

# maybe I dont need a stage2
if [ ! -z "$FILEPACKAGES" ]; then
	echo "Stage2"
	. do_stage2.sh
fi


if [ "$BOOT_TYPE" == "grub" ]; then
	. prepare_iso_grub.sh
else if [ "$BOOT_TYPE" == "isolinux" ]; then
	. prepare_iso_isolinux.sh
else
	error "Unknown BOOT_TYPE ($BOOT_TYPE). Must be grub or isolinux"
	exit 1
fi; fi
